@@ -9,6 +9,7 @@
 #' @param barra barblot if TRUE
 #' @param lbarra length of barplot
 #' @param col color vector
+#' @param map function call to plot map lines, points and annotation (experimental)
 #' @param verbose if TRUE print some information
 #' @param ... Arguments to be passed to plot methods
 #'
@@ -43,7 +44,7 @@
 #'data(Lights)
 #'to_wrf(Lights, files[1], total = 1521983, name = "E_CO")
 #'
-#'wrf_plot(files[1], "E_CO")
+#' wrf_plot(files[1], "E_CO")
 #'}
 wrf_plot <- function(file = file.choose(),
                      name = NA,
@@ -51,9 +52,14 @@ wrf_plot <- function(file = file.choose(),
                      nivel = 1,
                      barra = T,
                      lbarra = 0.2,
-                     col = cptcity::cpt(n = 13),
-                     verbose = T,
+                     col = cptcity::cpt(n = 20, rev = T),
+                     map = NULL,
+                     verbose = TRUE,
                      ...){
+
+  oldpar <- par(no.readonly = TRUE)
+  on.exit(par(oldpar))
+
   wrfchem <- ncdf4::nc_open(file)                                      # iteractive
   if(is.na(name)){                                                     # nocov start
     name  <- menu(names(wrfchem$var)[c(-1,-2,-3)], title = "Choose the variable:")
@@ -75,10 +81,10 @@ wrf_plot <- function(file = file.choose(),
   ncdf4::nc_close(wrfchem)
 
   if(length(dim(POL)) == 3){
-    POL <- POL[,,max(time,nivel,na.rm=TRUE)]               # nocov
+    POL <- POL[,,max(time,nivel,na.rm=TRUE)]        # nocov
   }
   if(length(dim(POL)) == 4){
-    POL <- POL[,,nivel,time]         # nocov
+    POL <- POL[,,nivel,time]                        # nocov
   }
 
   if(verbose){
@@ -104,6 +110,7 @@ wrf_plot <- function(file = file.choose(),
                                 plot.axes,
                                 key.title,
                                 key.axes,
+                                map = map,
                                 asp = NA,
                                 xaxs = "i",
                                 yaxs = "i",
@@ -111,6 +118,7 @@ wrf_plot <- function(file = file.choose(),
                                 axes = TRUE,
                                 frame.plot = axes,
                                 mar, ...) {
+
     if (missing(z)) {
       if (!missing(x)) {                             # nocov
         if (is.list(x)) {                            # nocov
@@ -188,6 +196,9 @@ wrf_plot <- function(file = file.choose(),
   mtext(paste("WRF-Chem emissions - Time:", Times[time]), 3, line = 0.8)
   mtext("Latitude", 2, line = 2.2,cex = 1.2, las=0)
   mtext("Longitude", 1, line = 2.2,cex = 1.2)
+  if(!is.null(map)){
+    map                 # nocov
+  }
   if(barra){
     par(mar = c(3.5, 1, 3, 4))
     barras(POL, col = col)
