@@ -7,7 +7,8 @@ wrf_create(wrfinput_dir          = system.file("extdata", package = "eixport"),
             frames_per_auxinput5 = 1,
             verbose              = TRUE)
 
-f1 <- dir(path = file.path(tempdir(), "EMISS"), pattern = "wrfchemi_d02", full.names = T)
+f1 <- dir(path = file.path(tempdir(), "EMISS"),
+          pattern = "wrfchemi_d02", full.names = T)
 
 f2 <- unzip(zipfile = paste0(system.file("extdata", package = "eixport"),
                              "/wrfchemi_d02_2011-08-02.zip"),
